//#include "cc_os_defines.h"
//#include "host.h"
#include <asm/io.h>
#include <asm/system.h>
#include <asm/fixmap.h>
#include <asm/apicdef.h>
#include <xen/spinlock.h>

unsigned int
OS_READ_REG_UINT32(
    unsigned int * Reg
    )
{
	return readl(Reg);
}

void
OS_WRITE_REG_UINT32(
    unsigned int * Reg,
    unsigned int   Value
    )
{
	writel(Value,Reg);
}


// - misc apic defines
#define DELIVERY_PENDING        0x00001000
#define DESTINATION_MASK        0xFF000000
#define DESTINATION_SHIFT       24
#define DELIVERY_MODE_MASK      0x00000700
#define DELIVER_SMI             0x00000200
#define DELIVER_NMI             0x00000400
#define DELIVER_INIT            0x00000500
#define DELIVER_STARTUP         0x00000600
#define PHYSICAL_DESTINATION    0x00000000
#define LOGICAL_DESTINATION     0x00000800
#define EDGE_TRIGGERED          0x00000000
#define LEVEL_ASSERT            0x00004000
#define INT_MASKED              0x00010000
#define ICR_SHORTHAND_MASK      0x000C0000
#define ICR_USE_DEST_FIELD      0x00000000
#define ICR_SELF                0x00040000
#define ICR_ALL_INCL_SELF       0x00080000
#define ICR_ALL_EXCL_SELF       0x000C0000


#define APIC_REG_UINT32(Base,ByteOffset) \
        (((unsigned int *)(Base))[(ByteOffset)/sizeof(unsigned int)])
#define LU_ID_REGISTER    0x00000020
#define LU_INT_CMD_LOW    0x00000300
#define LU_INT_CMD_HIGH   0x00000310
#define LU_INT_VECTOR_1   0x00000360

// - used to poll until the apic is not busy
#define STALL_WHILE_APIC_BUSY(ApicBase) \
    do { \
        while (OS_READ_REG_UINT32( \
                    &APIC_REG_UINT32((ApicBase),LU_INT_CMD_LOW)) & \
               DELIVERY_PENDING) \
            ; \
    } while(0)

#define APIC_SMI_TO_PHYS_DEST  (DELIVER_SMI | PHYSICAL_DESTINATION | \
                                ICR_USE_DEST_FIELD | EDGE_TRIGGERED)

#define SMI_DEST_ALL   0xffffffff
#define SMI_DEST_SELF  0xfffffffe

// - get apic processor id 
#define APIC_PROC_ID(ApicBase) \
    ((OS_READ_REG_UINT32(&APIC_REG_UINT32((ApicBase),LU_ID_REGISTER)) \
     & 0x0F000000) >> 24)

unsigned int HostGetProcId(void)
{
    return APIC_PROC_ID(APIC_BASE);
}

void host_request_smi(unsigned int dest)
{
	unsigned char ProcId;
	unsigned long flags;

	local_irq_save(flags);

	STALL_WHILE_APIC_BUSY(APIC_BASE);

	switch (dest) {
	case SMI_DEST_ALL:
		OS_WRITE_REG_UINT32(&APIC_REG_UINT32(APIC_BASE,LU_INT_CMD_HIGH),
			(unsigned int)(0xff << DESTINATION_SHIFT));
	    break;
	case SMI_DEST_SELF:
	default:
		ProcId = (unsigned char)(dest == SMI_DEST_SELF ? HostGetProcId() : dest);
		OS_WRITE_REG_UINT32(&APIC_REG_UINT32(APIC_BASE,LU_INT_CMD_HIGH),
			ProcId << DESTINATION_SHIFT);
	}

	OS_WRITE_REG_UINT32(&APIC_REG_UINT32(APIC_BASE,LU_INT_CMD_LOW),
			APIC_SMI_TO_PHYS_DEST);

	STALL_WHILE_APIC_BUSY(APIC_BASE);

	local_irq_restore(flags);
}
