#ifndef _COMPAT_PLATFORM_H
#define _COMPAT_PLATFORM_H
#include <xen/compat.h>
#include <public/platform.h>
#pragma pack(4)
#include "xen.h"
#pragma pack(4)
#include "stratus.h"
#pragma pack(4)
struct compat_pf_settime {

    uint32_t secs;
    uint32_t nsecs;
    uint64_t system_time;
};
typedef struct compat_pf_settime compat_pf_settime_t;
DEFINE_COMPAT_HANDLE(compat_pf_settime_t);
struct compat_pf_add_memtype {

    compat_pfn_t mfn;
    uint64_t nr_mfns;
    uint32_t type;

    uint32_t handle;
    uint32_t reg;
};
typedef struct compat_pf_add_memtype compat_pf_add_memtype_t;
DEFINE_COMPAT_HANDLE(compat_pf_add_memtype_t);
struct compat_pf_del_memtype {

    uint32_t handle;
    uint32_t reg;
};
typedef struct compat_pf_del_memtype compat_pf_del_memtype_t;
DEFINE_COMPAT_HANDLE(compat_pf_del_memtype_t);

struct compat_pf_read_memtype {

    uint32_t reg;

    compat_pfn_t mfn;
    uint64_t nr_mfns;
    uint32_t type;
};
typedef struct compat_pf_read_memtype compat_pf_read_memtype_t;
DEFINE_COMPAT_HANDLE(compat_pf_read_memtype_t);

struct compat_pf_microcode_update {

    COMPAT_HANDLE(void) data;
    uint32_t length;
};
typedef struct compat_pf_microcode_update compat_pf_microcode_update_t;
DEFINE_COMPAT_HANDLE(compat_pf_microcode_update_t);

struct compat_pf_platform_quirk {

    uint32_t quirk_id;
};
typedef struct compat_pf_platform_quirk compat_pf_platform_quirk_t;
DEFINE_COMPAT_HANDLE(compat_pf_platform_quirk_t);

struct compat_pf_firmware_info {

    uint32_t type;
    uint32_t index;

    union {
        struct {

            uint8_t device;
            uint8_t version;
            uint16_t interface_support;

            uint16_t legacy_max_cylinder;
            uint8_t legacy_max_head;
            uint8_t legacy_sectors_per_track;

            COMPAT_HANDLE(void) edd_params;
        } disk_info;
        struct {
            uint8_t device;
            uint32_t mbr_signature;
        } disk_mbr_signature;
        struct {

            uint8_t capabilities;
            uint8_t edid_transfer_time;

            COMPAT_HANDLE(uint8_t) edid;
        } vbeddc_info;
    } u;
};
typedef struct compat_pf_firmware_info compat_pf_firmware_info_t;
DEFINE_COMPAT_HANDLE(compat_pf_firmware_info_t);

typedef struct compat_pf_stratus_call compat_pf_stratus_call_t;
DEFINE_COMPAT_HANDLE(compat_pf_stratus_call_t);

struct compat_pf_change_freq {

    uint32_t flags;
    uint32_t cpu;
    uint64_t freq;
};
typedef struct compat_pf_change_freq compat_pf_change_freq_t;
DEFINE_COMPAT_HANDLE(compat_pf_change_freq_t);
struct compat_pf_getidletime {

    COMPAT_HANDLE(uint8_t) cpumap_bitmap;

    uint32_t cpumap_nr_cpus;

    COMPAT_HANDLE(uint64_t) idletime;

    uint64_t now;
};
typedef struct compat_pf_getidletime compat_pf_getidletime_t;
DEFINE_COMPAT_HANDLE(compat_pf_getidletime_t);

struct compat_platform_op {
    uint32_t cmd;
    uint32_t interface_version;
    union {
        struct compat_pf_settime settime;
        struct compat_pf_add_memtype add_memtype;
        struct compat_pf_del_memtype del_memtype;
        struct compat_pf_read_memtype read_memtype;
        struct compat_pf_microcode_update microcode;
        struct compat_pf_platform_quirk platform_quirk;
        struct compat_pf_firmware_info firmware_info;
 struct compat_pf_change_freq change_freq;
 struct compat_pf_getidletime getidletime;
 struct compat_pf_stratus_call stratus_call;
        uint8_t pad[128];
    } u;
};
typedef struct compat_platform_op compat_platform_op_t;
DEFINE_COMPAT_HANDLE(compat_platform_op_t);
#pragma pack()
#endif /* _COMPAT_PLATFORM_H */
